@@ -39,6 +39,8 @@ THE SOFTWARE.
 
 #include "xmlstar.h"
 
+gOptions globalOptions;
+
 static const xmlChar* XMLSTAR_NS = BAD_CAST "http://xmlstar.sourceforge.net";
 static const xmlChar* XMLSTAR_NS_PREFIX = BAD_CAST "xstar";
 
@@ -77,8 +79,24 @@ usage(int argc, char **argv, exit_status status)
 }  
 
 /**
- * Error reporting function
+ *  Initialize global command line options
  */
+void
+gInitOptions(gOptionsPtr ops)
+{
+    ops->quiet = 0;
+}
+
+/**
+ * Error reporting functions
+ */
+void reportGenericError(void* ctx, const char * msg, ...) {
+    /* do nothing */
+}
+
+/* by default errors are reported */
+static ErrorInfo errorInfo = { NULL, NULL, VERBOSE };
+
 void reportError(void *ptr, xmlErrorPtr error)
 {
     ErrorInfo *errorInfo = (ErrorInfo*) ptr;
@@ -132,6 +150,13 @@ void reportError(void *ptr, xmlErrorPtr error)
     }
 }
 
+void
+suppressErrors(void)
+{
+    xmlSetGenericErrorFunc(NULL, reportGenericError);
+    errorInfo.verbose = QUIET;
+}
+
 #define CHECK_MEM(ret) if (!ret) \
         (fprintf(stderr, "out of memory\n"), exit(EXIT_INTERNAL_ERROR))
 
@@ -157,6 +182,55 @@ xstrdup(const char *str)
     return ret;
 }
 
+/**
+ *  Parse global command line options
+ */
+void
+gParseOptions(gOptionsPtr ops, int *argc, char **argv)
+{
+    int i, j;
+    i = 1;
+    while(i < *argc)
+    {
+        if (!strcmp(argv[i], "--quiet") || !strcmp(argv[i], "-q"))
+        {
+            ops->quiet = 1;
+            i++;
+        }
+        else if (!strcmp(argv[i], "--version"))
+        {
+            fprintf(stdout, "%s\n"
+                "compiled against libxml2 %s, linked with %s\n"
+                "compiled against libxslt %s, linked with %s\n",
+                VERSION,
+                LIBXML_DOTTED_VERSION, xmlParserVersion,
+                LIBXSLT_DOTTED_VERSION, xsltEngineVersion);
+            exit(EXIT_SUCCESS);
+        }
+        else if (!strcmp(argv[i], "--help"))
+        {
+            usage(*argc, argv, EXIT_SUCCESS);
+        }
+        else if (argv[i][0] != '-')
+        {
+            /* remove parsed arguments */
+            i--;
+            for (j = 1; j < *argc; j++) {
+                if (j < *argc - i)
+                    argv[j] = argv[j + i];
+                else
+                    argv[j] = 0;
+            }
+            *argc -= i;
+            return;
+        }
+        else
+        {
+            usage(*argc, argv, EXIT_BAD_ARGS);
+        }
+    }
+}
+
 /**
  *  This is the main function
  */
@@ -164,11 +238,15 @@ int
 main(int argc, char **argv)
 {
     int ret = 0;
-    /* by default errors are reported */
-    static ErrorInfo errorInfo = { NULL, NULL, VERBOSE };
 
     xmlMemSetup(free, xmalloc, xrealloc, xstrdup);
+    
+    gInitOptions(&globalOptions);
+    gParseOptions(&globalOptions, &argc, argv);
+    
     xmlSetStructuredErrorFunc(&errorInfo, reportError);
+    if (globalOptions.quiet)
+        suppressErrors();
 
     if (argc <= 1)
     {
@@ -222,22 +300,11 @@ main(int argc, char **argv)
     {
         ret = escMain(argc, argv, 0);
     }
-    else if (!strcmp(argv[1], "--version"))
-    {
-        fprintf(stdout, "%s\n"
-            "compiled against libxml2 %s, linked with %s\n"
-            "compiled against libxslt %s, linked with %s\n",
-            VERSION,
-            LIBXML_DOTTED_VERSION, xmlParserVersion,
-            LIBXSLT_DOTTED_VERSION, xsltEngineVersion);
-        ret = EXIT_SUCCESS;
-    }
     else
     {
-        usage(argc, argv, strcmp(argv[1], "--help") == 0?
-            EXIT_SUCCESS : EXIT_BAD_ARGS);
+        usage(argc, argv, EXIT_BAD_ARGS);
     }
-    
+
     exit(ret);
 }
 
@@ -284,6 +351,12 @@ static void bad_ns_opt(const char *msg)
     exit(EXIT_BAD_ARGS);
 }
 
+const char* DEFAULT_NS_FAIL_MESSAGE =
+    "None of the XPaths matched; to match a node in the default namespace\n"
+    "use '_' as the prefix (see section 5.1 in the manual).\n"
+    "For instance, use /_:node instead of /node\n";
+const xmlChar *default_ns = NULL;
+
 #define MAX_NS_ARGS    256
 xmlChar *ns_arr[2 * MAX_NS_ARGS + 1];
 
