@@ -217,8 +217,16 @@ extract_ns_defs(xmlDocPtr doc, xmlXPathContextPtr ctxt)
     if (!root) return;
 
     for (nsDef = root->nsDef; nsDef; nsDef = nsDef->next) {
-        if (nsDef->prefix != NULL) /* can only register ns with prefix */
+        if (nsDef->prefix != NULL) { /* can only register ns with prefix */
             xmlXPathRegisterNs(ctxt, nsDef->prefix, nsDef->href);
+        } else {
+            default_ns = nsDef->href;
+        }
+    }
+
+    if (default_ns) {
+        xmlXPathRegisterNs(ctxt, BAD_CAST "_", default_ns);
+        xmlXPathRegisterNs(ctxt, BAD_CAST "DEFAULT", default_ns);
     }
 }
 
@@ -434,10 +442,12 @@ edMove(xmlDocPtr doc, xmlNodeSetPtr nodes, xmlNodePtr to)
 
 /**
  *  Loop through array of operations and perform them
+ *  @return number of successful operations
  */
-static void
+static int
 edProcess(xmlDocPtr doc, const XmlEdAction* ops, int ops_count)
 {
+    int op_applied = 0;
     int k;
     xmlXPathContextPtr ctxt = xmlXPathNewContext(doc);
     /* NOTE: later registrations override earlier ones */
@@ -480,6 +490,8 @@ edProcess(xmlDocPtr doc, const XmlEdAction* ops, int ops_count)
         if (!res || res->type != XPATH_NODESET || !res->nodesetval) continue;
         nodes = res->nodesetval;
 
+        op_applied += (nodes->nodeNr > 0);
+
         switch (ops[k].op)
         {
             case XML_ED_DELETE:
@@ -524,6 +536,8 @@ edProcess(xmlDocPtr doc, const XmlEdAction* ops, int ops_count)
     xmlDeregisterNodeDefault(NULL);
 
     xmlXPathFreeContext(ctxt);
+
+    return op_applied;
 }
 
 /**
@@ -533,6 +547,7 @@ static void
 edOutput(const char* filename, const XmlEdAction* ops, int ops_count,
     const edOptions* g_ops)
 {
+    int op_applied;
     xmlDocPtr doc;
     int save_options =
 #if LIBXML_VERSION >= 20708
@@ -553,7 +568,7 @@ edOutput(const char* filename, const XmlEdAction* ops, int ops_count,
         exit(EXIT_BAD_FILE);
     }
 
-    edProcess(doc, ops, ops_count);
+    op_applied = edProcess(doc, ops, ops_count);
 
     /* avoid getting ASCII CRs in UTF-16/UCS-(2,4) text */
     if ((xmlStrcasestr(doc->encoding, BAD_CAST "UTF") == 0
@@ -570,8 +585,11 @@ edOutput(const char* filename, const XmlEdAction* ops, int ops_count,
     save = xmlSaveToFilename(g_ops->inplace? filename : "-", NULL, save_options);
     xmlSaveDoc(save, doc);
     xmlSaveClose(save);
-
     xmlFreeDoc(doc);
+
+    if (!op_applied && ops_count > 0 && default_ns && !globalOptions.quiet) {
+        fprintf(stderr, DEFAULT_NS_FAIL_MESSAGE);
+    }
 }
 
 /**
@@ -617,14 +635,21 @@ static void
 parseInsertionArgs(XmlEdOp op_type, XmlEdAction* op,
     char *const*const argv, int *argi)
 {
+    XmlEdArg arg;
     op->op = op_type;
     op->arg1 = nextArg(argv, argi);
     parseNextArg(argv, argi, OPT_JUST_TYPE);
     op->type = parseNextArg(argv, argi, OPT_NODE_TYPE);
     parseNextArg(argv, argi, OPT_JUST_NAME);
     op->arg3 = nextArg(argv, argi);
-    parseNextArg(argv, argi, OPT_JUST_VAL);
-    op->arg2 = nextArg(argv, argi);
+    /* test if value is given */
+    op->arg2 = 0;
+    arg = argv[*argi];
+    if (!arg) return;
+    if (!strcmp(arg, "-v") || !strcmp(arg, "--value")) {
+        parseNextArg(argv, argi, OPT_JUST_VAL);
+        op->arg2 = nextArg(argv, argi);
+    }
 }
 
 /**
