@@ -173,7 +173,7 @@ selUsage(const char *argv0, exit_status status)
 void
 selInitOptions(selOptionsPtr ops)
 {
-    ops->quiet = 0;
+    ops->quiet = globalOptions.quiet;
     ops->printXSLT = 0;
     ops->printRoot = 0;
     ops->outText = 0;
@@ -635,6 +635,12 @@ extract_ns_defs(xmlNodePtr root, xmlDocPtr style_tree)
 
     for (nsDef = root->nsDef; nsDef; nsDef = nsDef->next) {
         xmlNewNs(style_root, nsDef->href, nsDef->prefix);
+        if (nsDef->prefix == NULL)
+            default_ns = nsDef->href;
+    }
+    if (default_ns) {
+        xmlNewNs(style_root, default_ns, BAD_CAST "_");
+        xmlNewNs(style_root, default_ns, BAD_CAST "DEFAULT");
     }
 }
 
@@ -702,6 +708,7 @@ selMain(int argc, char **argv)
     xsltInitOptions(&xsltOps);
     start = selParseOptions(&ops, argc, argv);
     xml_options |= XML_PARSE_NOENT; /* substitute entities */
+    xml_options |= XML_PARSE_DTDATTR; /* use default attrib values */
     xml_options |= ops.nonet? XML_PARSE_NONET : 0;
     xsltOps.nonet = ops.nonet;
     xsltOps.noblanks = ops.noblanks;
@@ -732,6 +739,10 @@ selMain(int argc, char **argv)
     if (i == argc)
         do_file("-", style_tree, xml_options, &ops, &xsltOps, &status);
 
+    if (status != EXIT_SUCCESS && default_ns && !ops.quiet) {
+        fprintf(stderr, DEFAULT_NS_FAIL_MESSAGE);
+    }
+
     /* 
      * Shutdown libxml
      */
