@@ -31,11 +31,23 @@ typedef struct _errorInfo {
 } ErrorInfo;
 
 void reportError(void *ptr, xmlErrorPtr error);
+void suppressErrors(void);
+
+typedef struct _gOptions {
+    int quiet;            /* no error output */
+} gOptions;
+
+typedef gOptions *gOptionsPtr;
+
+extern gOptions globalOptions;
 
 void registerXstarVariable(xmlXPathContextPtr ctxt,
     const char* name, xmlXPathObjectPtr value);
 void registerXstarNs(xmlXPathContextPtr ctxt);
 
+const char* DEFAULT_NS_FAIL_MESSAGE;
+extern const xmlChar *default_ns;
+
 int parseNSArr(xmlChar** ns_arr, int* plen, int argc, char **argv);
 void cleanupNSArr(xmlChar **ns_arr);
 extern xmlChar *ns_arr[];
